@@ -183,6 +183,7 @@ bool CHttpDownloader::ParseResult(const std::string& name, const std::string& js
 		}
 		res.push_back(dl);
 	}
+	LOG_DEBUG("Parsed %d results", res.size());
 	return true;
 }
 
@@ -337,7 +338,7 @@ bool CHttpDownloader::setupDownload(DownloadData* piece)
 	CURL* curle = piece->curlw->GetHandle();
 	piece->mirror=piece->download->getFastestMirror();
 	if (piece->mirror==NULL) {
-		LOG_ERROR("No mirror found");
+		LOG_ERROR("No mirror found for %s", piece->download->name.c_str());
 		return false;
 	}
 
@@ -368,9 +369,11 @@ bool CHttpDownloader::setupDownload(DownloadData* piece)
 
 		//this sets the header If-Modified-Since -> downloads only when remote file is newer than local file
 		const long timestamp = piece->download->file->GetTimestamp();
-		curl_easy_setopt(curle, CURLOPT_TIMECONDITION, CURL_TIMECOND_IFMODSINCE);
-		curl_easy_setopt(curle, CURLOPT_TIMEVALUE, timestamp );
-		curl_easy_setopt(curle, CURLOPT_FILETIME, 1);
+		if ((timestamp >= 0) && (piece->download->hash == nullptr)) { //timestamp known + hash not known -> only dl when changed
+			curl_easy_setopt(curle, CURLOPT_TIMECONDITION, CURL_TIMECOND_IFMODSINCE);
+			curl_easy_setopt(curle, CURLOPT_TIMEVALUE, timestamp );
+			curl_easy_setopt(curle, CURLOPT_FILETIME, 1);
+		}
 	}
 	return true;
 }
@@ -525,15 +528,11 @@ bool CHttpDownloader::download(std::list<IDownload*>& download, int max_parallel
 			DownloadData* dlData=new DownloadData();
 			dlData->download=dl;
 			if (!setupDownload(dlData)) { //no piece found (all pieces already downloaded), skip
-				delete dlData;
-				if (dl->state!=IDownload::STATE_FINISHED) {
-					LOG_ERROR("no piece found");
-					return false;
-				}
-			} else {
-				downloads.push_back(dlData);
-				curl_multi_add_handle(curlm, dlData->curlw->GetHandle());
+				LOG_ERROR("Failed to setup download %d/%d", i, count);
+				continue;
 			}
+			downloads.push_back(dlData);
+			curl_multi_add_handle(curlm, dlData->curlw->GetHandle());
 		}
 	}
 	if (downloads.empty()) {
