@@ -379,17 +379,14 @@ void ChatPanel::OutputLine(const wxString& message, const wxColour& col, bool sh
 	if (!m_chatlog_text)
 		return;
 
-	wxDateTime now = wxDateTime::Now();
-	wxTextAttr timestyle(sett().GetChatColorTime(), sett().GetChatColorBackground());
-	wxTextAttr chatstyle(col, sett().GetChatColorBackground());
-
 	ChatLine newline;
-	newline.chat = wxString(message.c_str());
-	newline.chatstyle = chatstyle;
+	newline.chat = message;
+	newline.chatstyle = wxTextAttr(col, sett().GetChatColorBackground());
 	if (showtime) {
+		wxDateTime now = wxDateTime::Now();
 		newline.time = _T( "[" ) + now.Format(_T( "%H:%M:%S" )) + _T( "]" );
-		newline.timestyle = timestyle;
-		m_chat_log.AddMessage(message);
+		newline.timestyle = wxTextAttr(sett().GetChatColorTime(), sett().GetChatColorBackground());
+		m_chat_log.AddMessage(newline.time + _T(" ") + message);
 	} else {
 		newline.time.clear();
 	}
@@ -401,7 +398,6 @@ void ChatPanel::OutputLine(const wxString& message, const wxColour& col, bool sh
 	}
 }
 
-
 void ChatPanel::OutputLine(const ChatLine& line)
 {
 	const int numOfLines = m_chatlog_text->GetNumberOfLines();
@@ -420,7 +416,9 @@ void ChatPanel::OutputLine(const ChatLine& line)
 
 	if (!line.time.empty()) {
 		m_chatlog_text->SetDefaultStyle(line.timestyle);
-		m_chatlog_text->AppendText(line.time);
+		m_chatlog_text->AppendText(line.time + _T(" "));
+	} else {
+		m_chatlog_text->SetDefaultStyle(line.chatstyle);
 	}
 
 #ifndef __WXOSX_COCOA__
@@ -436,30 +434,15 @@ void ChatPanel::OutputLine(const ChatLine& line)
 		const wxColor oldcolor(line.chatstyle.GetTextColour());
 
 		while (m1.Len() > 0) {
-			const wxUniChar c = m1.GetChar(0);
-			if (c == 3 && m1.Len() > 1 && (m1.GetChar(1) >= 48 && m1.GetChar(1) <= 58)) { // Color
-				if (m1.Len() > 2 && (m1.GetChar(2) >= 48 && m1.GetChar(2) <= 58)) {
-					color = (int(m1.GetChar(1)) - 48) * 10 + (int(m1.GetChar(2)) - 48);
-					m1 = m1.Mid(3);
-				} else {
-					color = int(m1.GetChar(1)) - 48;
-					m1 = m1.Mid(2);
-				}
-
-				wxColor dummy(0, 0, 0);
-				if ((color > -1) && (color < long((sizeof(m_irc_colors) / sizeof(dummy))))) {
-					curcolor = m_irc_colors[color];
-				}
-
-			} else if (c == 2) { //Bold
-				bold = !bold;
-				m1 = m1.Mid(1);
-			} else if (c == 0x0F) { //Reset formatting
-				bold = false;
-				curcolor = oldcolor;
-				m1 = m1.Mid(1);
-			} else {
-
+			wxUniChar c = m1.GetChar(0);
+			wxUniChar tmp = c;
+			size_t len = 0;
+			unsigned char uc = c;
+			while(uc!=0x1f && uc!=0x1d && uc!=0x03 && uc!=0x02 && uc!=0x016 && uc!=0x0F && len < m1.Len()) { //get all text until first irc color is found
+				c = tmp;
+				tmp = m1.GetChar(len++);
+			}
+			if (len > 0) { //unformated text found, add as whole
 				wxFont font = oldfont; //isn't needed any more in wx3.0
 				at = line.chatstyle;
 				if (bold)
@@ -467,9 +450,44 @@ void ChatPanel::OutputLine(const ChatLine& line)
 				at.SetFont(font);
 				at.SetTextColour(curcolor);
 				m_chatlog_text->SetDefaultStyle(at);
-				m_chatlog_text->AppendText(m1.Mid(0, 1));
-				m1 = m1.Mid(1);
+				m_chatlog_text->AppendText(m1.Mid(0, len));
+				m1 = m1.Mid(len);
+				if (m1.Len() <= 0) { //no chars left, abort
+					break;
+				}
 			}
+			uc = c;
+			switch(uc) { //  http://en.wikichip.org/wiki/irc/colors
+				case 0x1f: //underline
+					break;
+				case 0x1d: //italics
+					break;
+				case 0x03: {
+					if (m1.Len() > 2 && (m1.GetChar(2) >= 48 && m1.GetChar(2) <= 58)) {
+						color = (int(m1.GetChar(1)) - 48) * 10 + (int(m1.GetChar(2)) - 48);
+						m1 = m1.Mid(2); //next chars
+					} else {
+						color = int(m1.GetChar(1)) - 48;
+						m1 = m1.Mid(1); //next char
+					}
+
+					wxColor dummy(0, 0, 0);
+					if ((color > -1) && (color < long((sizeof(m_irc_colors) / sizeof(dummy))))) {
+						curcolor = m_irc_colors[color];
+					}
+					break;
+				}
+				case 0x02: //bold
+					bold = !bold;
+					break;
+				case 0x16: //reverse;
+					break;
+				case 0x0F: //reset formating
+					bold = false;
+					curcolor = oldcolor;
+					break;
+			}
+			m1 = m1.Mid(1); //next char!
 		}
 		m_chatlog_text->AppendText(_T("\n"));
 	} else
@@ -566,9 +584,9 @@ void ChatPanel::Said(const wxString& who, const wxString& message)
 		wxString message2;
 		who2 = message.BeforeFirst('>').AfterFirst('<');
 		message2 = message.AfterFirst('>');
-		OutputLine(_T( " <" ) + who2 + _T( "> " ) + message2, col);
+		OutputLine(_T( "<" ) + who2 + _T( "> " ) + message2, col);
 	} else {
-		OutputLine(_T( " <" ) + who + _T( "> " ) + message, col);
+		OutputLine(_T( "<" ) + who + _T( "> " ) + message, col);
 	}
 
 
@@ -599,7 +617,7 @@ bool ChatPanel::ContainsWordToHighlight(const wxString& message) const
  */
 void ChatPanel::CheckForPromotion(const wxString& /*who*/, const wxString& action)
 {
-	if (m_reactOnPromoteEvents == false) { //If this feature disabled in options do nothing
+	if (!m_reactOnPromoteEvents) { //If this feature disabled in options do nothing
 		return;
 	}
 
@@ -610,9 +628,7 @@ void ChatPanel::CheckForPromotion(const wxString& /*who*/, const wxString& actio
 	//Detect event and notify user
 	//TODO: Rework for using array of regexps, not shit crap
 	if (action.Contains(promoteMessageTemplate) || action.Contains(promoteMessageTemplate2)) {
-		wxCommandEvent promoteEvent = wxCommandEvent(GlobalEventManager::GamePromotedEvent);
-		promoteEvent.SetString(action); //Send action string with that should be shown
-		GlobalEventManager::Instance()->Send(promoteEvent);
+		UiEvents::GetNotificationEventSender().SendEvent(UiEvents::NotficationData(UiEvents::GamePromoted, action));
 	}
 }
 
@@ -632,7 +648,7 @@ void ChatPanel::DidAction(const wxString& who, const wxString& action)
 
 	// change the image of the tab to show new events
 	SetIconHighlight(highlight_say);
-	OutputLine(_T( " * " ) + who + _T( " " ) + action, sett().GetChatColorAction());
+	OutputLine(_T( "* " ) + who + _T( " " ) + action, sett().GetChatColorAction());
 	if (m_type == CPT_User && (ui().GetActiveChatPanel() != this || !wxTheApp->IsActive())) {
 		const wxString msg = wxString::Format(_T("%s \n%s"), who.c_str(), action.Left(50).c_str());
 		UiEvents::GetNotificationEventSender().SendEvent(
@@ -647,7 +663,7 @@ void ChatPanel::Motd(const wxString& message)
 {
 	// change the image of the tab to show new events
 	SetIconHighlight(highlight_say);
-	OutputLine(_T( " ** motd ** " ) + message, sett().GetChatColorServer());
+	OutputLine(_T( "** motd ** " ) + message, sett().GetChatColorServer());
 }
 
 void ChatPanel::StatusMessage(const wxString& message)
@@ -657,25 +673,25 @@ void ChatPanel::StatusMessage(const wxString& message)
 	} else {
 		if (CPT_Server == m_type)
 			SetIconHighlight(highlight_important);
-		OutputLine(_T( " ** Server ** " ) + message, sett().GetChatColorServer());
+		OutputLine(_T( "** Server ** " ) + message, sett().GetChatColorServer());
 	}
 }
 
 void ChatPanel::ClientMessage(const wxString& message)
 {
-	OutputLine(_T( " ** " ) + message, sett().GetChatColorClient());
+	OutputLine(_T( "** " ) + message, sett().GetChatColorClient());
 }
 
 void ChatPanel::UnknownCommand(const wxString& command, const wxString& params)
 {
 	// change the image of the tab to show new events
 	SetIconHighlight(highlight_important);
-	OutputLine(_(" !! Command: \"") + command + _("\" params: \"") + params + _T( "\"." ), sett().GetChatColorError());
+	OutputLine(_("!! Command: \"") + command + _("\" params: \"") + params + _T( "\"." ), sett().GetChatColorError());
 }
 
 void ChatPanel::OutputError(const wxString& message)
 {
-	OutputLine(wxString::Format(_(" Error: %s"), message.c_str()), sett().GetChatColorError());
+	OutputLine(wxString::Format(_("Error: %s"), message.c_str()), sett().GetChatColorError());
 }
 
 
@@ -698,7 +714,7 @@ void ChatPanel::Joined(User& who)
 		if (m_type == CPT_Channel) {
 			SetIconHighlight(highlight_join_leave);
 		}
-		OutputLine(_T( " ** " ) + wxString::Format(_("%s joined %s."), TowxString(who.GetNick()).c_str(), GetChatTypeStr().c_str()), sett().GetChatColorJoinPart());
+		OutputLine(_T( "** " ) + wxString::Format(_("%s joined %s."), TowxString(who.GetNick()).c_str(), GetChatTypeStr().c_str()), sett().GetChatColorJoinPart());
 	}
 
 	if (m_show_nick_list && (m_nicklist != nullptr)) {
@@ -717,7 +733,7 @@ void ChatPanel::OnChannelJoin(User& who)
 		UpdateUserCountLabel();
 	}
 	if (m_display_joinitem) {
-		OutputLine(_T( " ** " ) + wxString::Format(_("%s joined %s."), TowxString(who.GetNick()).c_str(), GetChatTypeStr().c_str()), sett().GetChatColorJoinPart());
+		OutputLine(_T( "** " ) + wxString::Format(_("%s joined %s."), TowxString(who.GetNick()).c_str(), GetChatTypeStr().c_str()), sett().GetChatColorJoinPart());
 	}
 	// Also add the User to the TextCompletionDatabase
 	textcompletiondatabase.Insert_Mapping(TowxString(who.GetNick()), TowxString(who.GetNick()));
@@ -730,7 +746,7 @@ void ChatPanel::Parted(User& who, const wxString& message)
 	const wxString nick = TowxString(who.GetNick());
 	const bool wasactive = m_active_users.erase(nick) > 0;
 	if (m_display_joinitem || (wasactive && !who.IsBot())) {
-		OutputLine(_T( " ** " ) + wxString::Format(_("%s left %s (%s)."), nick.c_str(), GetChatTypeStr().c_str(), message.c_str()), sett().GetChatColorJoinPart());
+		OutputLine(_T( "** " ) + wxString::Format(_("%s left %s (%s)."), nick.c_str(), GetChatTypeStr().c_str(), message.c_str()), sett().GetChatColorJoinPart());
 	}
 	if (m_type == CPT_Channel) {
 		if (m_channel == 0)
@@ -769,13 +785,13 @@ void ChatPanel::SetTopic(const wxString& who, const wxString& message)
 	// change the image of the tab to show new events
 	if (m_topic_set)
 		SetIconHighlight(highlight_say);
-	OutputLine(_(" ** Channel topic:"), col);
+	OutputLine(_("** Channel topic:"), col);
 	wxStringTokenizer tkz(message, _T("\n"));
 	while (tkz.HasMoreTokens()) {
 		wxString msg = tkz.GetNextToken();
 		OutputLine(_T(" ") + msg, col);
 	}
-	OutputLine(_(" ** Set by ") + who, col);
+	OutputLine(_("** Set by ") + who, col);
 	m_topic_set = true;
 }
 
@@ -919,7 +935,7 @@ bool ChatPanel::Say(const wxString& message) //FIXME: remove all parsing / token
 
 		if (line == _T( "/ver" )) {
 			//!this instance is not replaced with GetAppname for sake of help/debug online
-			OutputLine(_(" You have SpringLobby v") + TowxString(getSpringlobbyVersion()), sett().GetChatColorNormal());
+			OutputLine(_("You have SpringLobby v") + TowxString(getSpringlobbyVersion()), sett().GetChatColorNormal());
 			return true;
 		}
 
@@ -1001,7 +1017,7 @@ bool ChatPanel::Say(const wxString& message) //FIXME: remove all parsing / token
 			}
 
 			m_server->SendCmd(STD_STRING(line), "");
-			OutputLine(_(" Sent: \"") + line + _("\""), sett().GetChatColorNormal());
+			OutputLine(_("Sent: \"") + line + _("\""), sett().GetChatColorNormal());
 		}
 	}
 	return true;
@@ -1035,14 +1051,14 @@ void ChatPanel::OnUserDisconnected()
 {
 	// change the image of the tab to show new events
 	SetIconHighlight(highlight_join_leave);
-	OutputLine(_(" ** User is now offline."), sett().GetChatColorJoinPart());
+	OutputLine(_("** User is now offline."), sett().GetChatColorJoinPart());
 }
 
 void ChatPanel::OnUserConnected()
 {
 	// change the image of the tab to show new events
 	SetIconHighlight(highlight_join_leave);
-	OutputLine(_(" ** User just got online."), sett().GetChatColorJoinPart());
+	OutputLine(_("** User just got online."), sett().GetChatColorJoinPart());
 }
 
 
@@ -1168,7 +1184,7 @@ void ChatPanel::SetBattle(IBattle* battle)
 	}
 
 	if (m_battle != NULL) {
-		OutputLine(_(" ** Left Battle."), sett().GetChatColorNotification());
+		OutputLine(_("** Left Battle."), sett().GetChatColorNotification());
 	}
 
 	if (battle == NULL) {
@@ -1176,7 +1192,7 @@ void ChatPanel::SetBattle(IBattle* battle)
 		return;
 	}
 
-	OutputLine(_(" ** Joined Battle."), sett().GetChatColorNotification());
+	OutputLine(_("** Joined Battle."), sett().GetChatColorNotification());
 
 	for (unsigned int i = 0; i < battle->GetNumUsers(); ++i) {
 		const wxString nick = TowxString(battle->GetUser(i).GetNick());
