@@ -300,7 +300,7 @@ void TASServer::Disconnect()
 		return;
 	}
 
-	if (IsConnected() == true) {
+	if (IsConnected()) {
 		SendCmd("EXIT " + STD_STRING(cfg().ReadString(_T("/Server/ExitMessage")))); // EXIT command for new protocol compatibility
 		m_sock->Disconnect();
 	}
@@ -461,10 +461,10 @@ void TASServer::Notify()
 		// Is it time for a nat traversal PING?
 		m_last_udp_ping = 0;
 		// Nat travelsal "ping"
-		if (m_battle_id != -1) {
+		if (BattleExists(m_battle_id)) {
 			IBattle* battle = GetCurrentBattle();
-			if ((battle) &&
-			    (battle->GetNatType() == NAT_Hole_punching || (battle->GetNatType() == NAT_Fixed_source_ports)) && !battle->GetInGame()) {
+			if ((battle != nullptr &&
+				battle->GetNatType() == NAT_Hole_punching || (battle->GetNatType() == NAT_Fixed_source_ports)) && !battle->GetInGame()) {
 				UdpPingTheServer(GetUserName());
 				if (battle->IsFounderMe()) {
 					UdpPingAllClients();
@@ -477,7 +477,7 @@ void TASServer::Notify()
 
 void TASServer::ExecuteCommand(const std::string& in)
 {
-	wxLogMessage(_T("%s"), TowxString(in).c_str());
+	wxLogDebug(_T("%s"), TowxString(in).c_str());
 	wxString cmd;
 	wxString params = TowxString(in);
 	long replyid = 0;
